@@ -64,6 +64,7 @@ class HandWheel:
             self.jog_speed[key] = float(val.strip())
         self.write_char = self.write_char.encode("utf-8")
         while True:
+            print("-->", self.serial_status)
             if self.serial_status:
                 if self.jog_count_time > 1:
                     self.do_jog()
@@ -77,6 +78,7 @@ class HandWheel:
                 if count != 0:
                     recv = self.serial.read(count)
                     recv_str = str(binascii.b2a_hex(recv))[6:34]
+                    print("--->", recv_str)
                 self.serial.flushInput()
                 self.jog_count_time = self.jog_count_time + 1
                 self.serial.write(self.write_char)
